public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* Re: BUG Report 2.4.0-test11-pre3: NMI Watchdoch detected LOCKUP  atCPU[01]
       [not found] <3A11AE6E.22AB1A32@windeath.2y.net>
@ 2000-11-15 19:20 ` Gert Wollny
  2000-11-16  5:12   ` James M
  0 siblings, 1 reply; 2+ messages in thread
From: Gert Wollny @ 2000-11-15 19:20 UTC (permalink / raw)
  To: James M; +Cc: linux-kernel, twaugh

[-- Attachment #1: Type: TEXT/PLAIN, Size: 549 bytes --]

Hello,

i think it got it nailed, please try the attached patch (it is against
11-pre4, but it should work against all test11).

Explanation: 
with test7-pre6 in the  imm-module the new scsi - code was enabled (see
imm.h).
This causes the locking of the io_request_lock in scsi_register_host 
(scsi.c) during detection of the ZIP drive. Seems, that the request_module
call for the parport_pc doesn't like this.
The patch does, what the comment in scsi.c suggests: Enable the new code
only, after the drive is detected.

Have a nice day

Gert




 


[-- Attachment #2: the patch --]
[-- Type: TEXT/PLAIN, Size: 1809 bytes --]

diff -ru 2.4.0-test11-pre4/drivers/scsi/imm.h 2.4.0-test11-pre4-my/drivers/scsi/imm.h
--- 2.4.0-test11-pre4/drivers/scsi/imm.h	Wed Nov 15 19:40:44 2000
+++ 2.4.0-test11-pre4-my/drivers/scsi/imm.h	Wed Nov 15 20:01:11 2000
@@ -10,7 +10,7 @@
 #ifndef _IMM_H
 #define _IMM_H
 
-#define   IMM_VERSION   "2.04 (for Linux 2.4.0)"
+#define   IMM_VERSION   "2.05 (for Linux 2.4.0)"
 
 /* 
  * 10 Apr 1998 (Good Friday) - Received EN144302 by email from Iomega.
@@ -60,6 +60,9 @@
  *    added CONFIG_SCSI_IZIP_SLOW_CTR option
  *                                                      [2.03]
  *  Fix kernel panic on scsi timeout.		20Aug00 [2.04]
+ *
+ *  Fix a lockup during detection of drive      14Nov00 [2.05]
+ *  <wollny@cns.mpg.de>
  */
 /* ------ END OF USER CONFIGURABLE PARAMETERS ----- */
 
@@ -172,7 +175,7 @@
                 eh_device_reset_handler:        NULL,                   \
                 eh_bus_reset_handler:           imm_reset,              \
                 eh_host_reset_handler:          imm_reset,              \
-		use_new_eh_code:		1,			\
+		use_new_eh_code:		0,			\
 		bios_param:		        imm_biosparam,		\
 		this_id:			7,			\
 		sg_tablesize:			SG_ALL,			\

^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: BUG Report 2.4.0-test11-pre3: NMI Watchdoch detected LOCKUP  atCPU[01]
  2000-11-15 19:20 ` BUG Report 2.4.0-test11-pre3: NMI Watchdoch detected LOCKUP atCPU[01] Gert Wollny
@ 2000-11-16  5:12   ` James M
  0 siblings, 0 replies; 2+ messages in thread
From: James M @ 2000-11-16  5:12 UTC (permalink / raw)
  To: Gert Wollny; +Cc: linux-kernel, twaugh

Gert Wollny wrote:
> 
> Hello,
> 
> i think it got it nailed, please try the attached patch (it is against
> 11-pre4, but it should work against all test11).
> 
> Explanation:
> with test7-pre6 in the  imm-module the new scsi - code was enabled (see
> imm.h).
> This causes the locking of the io_request_lock in scsi_register_host
> (scsi.c) during detection of the ZIP drive. Seems, that the request_module
> call for the parport_pc doesn't like this.
> The patch does, what the comment in scsi.c suggests: Enable the new code
> only, after the drive is detected.
> 
> Have a nice day

Thank you Gert. I turned off Winbond support as before and it truly is
"safe to say no" now. Your patch seems to work. Good Job.

Still outstanding:

If (mode=SPP && Zip100) Log_msg("Spp is godawful slow, set for EPP in
bios");
// I don't know off top of my head if Zip250 can use ECP or not
// Zip100 is EPP at best

Imm driver reports Zip100 at 101 MB

ECP/EPP setting in Bios yields SPP for Zip100. 1284 spec says you should
be able to set mode 100 to get EPP and even tho it's a M$ extension most
chipsets should support it.

Speed Sucks: Hdparm reports 496k/sec for EPP on a 64 MB buffered disk
read. 1284 spec says 500k/2 MB for EPP and Iomega says it can do 1.4 MB
sustained for Zip100. Not that it matters but SPP runs 96k/sec.

I'm coding up a parport-poker to get familiar then I'll take a stab at
these if someone doesn't beat me to it.

> 
> Gert
> 
> 
> 
>   ------------------------------------------------------------------------
>                           Name: imm-lockup.patch
>    imm-lockup.patch       Type: Plain Text (TEXT/PLAIN)
>                       Encoding: BASE64
>                    Description: the patch
-
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@vger.kernel.org
Please read the FAQ at http://www.tux.org/lkml/

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2000-11-16  5:38 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
     [not found] <3A11AE6E.22AB1A32@windeath.2y.net>
2000-11-15 19:20 ` BUG Report 2.4.0-test11-pre3: NMI Watchdoch detected LOCKUP atCPU[01] Gert Wollny
2000-11-16  5:12   ` James M

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
diff -ru 2.4.0-test11-pre4/drivers/scsi/imm.c 2.4.0-test11-pre4-my/drivers/scsi/imm.c
--- 2.4.0-test11-pre4/drivers/scsi/imm.c	Wed Nov 15 19:39:41 2000
+++ 2.4.0-test11-pre4-my/drivers/scsi/imm.c	Wed Nov 15 19:44:56 2000
@@ -212,8 +212,11 @@
 	    return 0;
 	try_again = 1;
 	goto retry_entry;
-    } else
-	return 1;		/* return number of hosts detected */
+    } else {
+	 /* now enable the new code */
+	 host->use_new_eh_code = 1;
+	 return 1;		/* return number of hosts detected */
+    }	 
 }
 
 /* This is to give the imm driver a way to modify the timings (and other